from __future__ import absolute_import

from . import fabd, system, git, release, virtualenv, nginx, django, pip, \
    postgres, mysql, supervisor, users, ssh, tar, gunicorn, uwsgi, rabbitmq, \
    apache, redis
from .base import setup_fabdeploy
from .containers import conf, DefaultConf
from .task import Task
